import { PrismaClient } from "@prisma/client";
import { Logger } from "@nestjs/common";



const prisma = new PrismaClient();

// https://www.prisma.io/docs/orm/prisma-client/queries/crud#deleting-all-data-with-raw-sql--truncate
async function clearDatabase() {
  const models = await prisma.$queryRaw<
    Array<{ tablename: string }>
  >`SELECT tablename FROM pg_tables WHERE schemaname='public'`;

  const tables = models
    .map(({ tablename }) => tablename)
    .filter((name) => name !== "_prisma_migrations")
    .map((name) => `"public"."${name}"`)
    .join(", ");

  await prisma.$executeRawUnsafe(
    
    `TRUNCATE TABLE ${tables} RESTART IDENTITY CASCADE;`
  );
}


async function main() {
  const args = process.argv.slice(2);
  const shouldReset = args.includes("--clear");

  if (shouldReset) {
    await clearDatabase();
  }

}

main()
  .then(async () => {
    Logger.log("Seeding complete!");
    await prisma.$disconnect();
  })
  .catch(async (e) => {
    Logger.fatal(e);
    await prisma.$disconnect();
    process.exit(1);
  });
