import { Injectable, Logger } from "@nestjs/common";
import { EmailTemplate, SendEmailInput } from "./types";


@Injectable()
export class EmailService {
  private readonly apiKey: string;

  constructor() {
    this.apiKey = process.env.BREVO_API_KEY!;
  }

  async sendEmail<T extends EmailTemplate>(input: SendEmailInput<T>) {
    const { to, params } = input;
console.log(input);
    const receivers = Array.isArray(to)
      ? to.map((email) => ({ email }))
      : [{ email: to }];

    try {
      const res = await fetch("https://api.brevo.com/v3/smtp/email", {
        method: "POST",
        headers: {
          "api-key": this.apiKey,
          "Content-Type": "application/json"
        },
        body: JSON.stringify({
          to: receivers,
          templateId:2,
          params:{
            firstName: "Joe"
          },
        })
      });

      return await res.json();
    } catch (error) {
      Logger.error(error, "EmailService.sendEmail");
    }
  }
}