import type { OnModuleDestroy, OnModuleInit } from "@nestjs/common";
import { Injectable, Logger } from "@nestjs/common";
import { Prisma, PrismaClient } from "@prisma/client";

@Injectable()
export class PrismaService
  extends PrismaClient<Prisma.PrismaClientOptions, "query">
  implements OnModuleInit, OnModuleDestroy
{
  constructor() {
    super({
      log: [
        { emit: "event", level: "query" },
        { emit: "stdout", level: "info" },
        { emit: "stdout", level: "warn" },
        { emit: "stdout", level: "error" }
      ],
      errorFormat: process.env.NODE_ENV === "production" ? "minimal" : "pretty"
    });
    // uncomment the following block if you want to log queries in development
    // if (process.env.NODE_ENV === "development") {
    //   this.$on("query", (event) => {
    //     Logger.debug(
    //       `${event.query}\n${event.params} - ${event.duration}ms`,
    //       PrismaService.name
    //     );
    //   });
    // }
  }

  async onModuleInit() {
    try {
      await this.$connect();
    } catch (error) {
      Logger.error(error);
    }
  }

  async onModuleDestroy() {
    await this.$disconnect();
  }
}
