import { HttpException, Module } from "@nestjs/common";
import { ConfigModule } from "@nestjs/config";
import { APP_INTERCEPTOR } from "@nestjs/core";
import { RavenInterceptor, RavenModule } from "nest-raven";

import { PrismaModule } from "./api/prisma/prisma.module";
import { AppController } from "./app.controller";
import { EmailModule } from './api/email/email.module';
import { LeadsModule } from './api/leads/leads.module';

@Module({
  imports: [ConfigModule.forRoot(), PrismaModule, RavenModule, EmailModule, LeadsModule],
  controllers: [AppController],
  providers: [
    {
      provide: APP_INTERCEPTOR,
      useValue: new RavenInterceptor({
        filters: [
          {
            type: HttpException,
            filter: (exception: HttpException) => exception.getStatus() < 500
          }
        ]
      })
    }
  ]
})
export class AppModule {}
